pub struct Handle<'a, V> { /* private fields */ }Expand description
A handle to a view which has been built into the tree.
Implementations
Sourceimpl<V> Handle<'_, V>
impl<V> Handle<'_, V>
Sourcepub fn lock_focus_to_within(self) -> Handle<'_, V>
pub fn lock_focus_to_within(self) -> Handle<'_, V>
Stop the user from tabbing out of a subtree, which is useful for modal dialogs.
Sourcepub fn on_build<F>(self, callback: F) -> Handle<'_, V>where
F: Fn(&mut EventContext<'_>),
pub fn on_build<F>(self, callback: F) -> Handle<'_, V>where
F: Fn(&mut EventContext<'_>),
Callback which is run when the view is built/rebuilt.
Sourcepub fn bind<R, T, F>(self, signal: R, closure: F) -> Handle<'_, V>
pub fn bind<R, T, F>(self, signal: R, closure: F) -> Handle<'_, V>
Creates a binding to the given resource and provides a closure which can be used to mutate the view through a handle.
Sourcepub fn needs_relayout(&mut self)
pub fn needs_relayout(&mut self)
Marks the view as needing a relayout.
Sourcepub fn needs_restyle(&mut self)
pub fn needs_restyle(&mut self)
Marks the view as needing a restyle.
Sourcepub fn needs_redraw(&mut self)
pub fn needs_redraw(&mut self)
Marks the view as needing a redraw.
Sourcepub fn bounds(&self) -> BoundingBox
pub fn bounds(&self) -> BoundingBox
Returns the bounding box of the view.
Sourcepub fn scale_factor(&self) -> f32
pub fn scale_factor(&self) -> f32
Returns the scale factor of the device.
Sourceimpl Handle<'_, Accordion>
impl Handle<'_, Accordion>
Sourcepub fn open(
self,
indices: impl Res<Vec<usize>> + 'static,
) -> Handle<'_, Accordion>
pub fn open( self, indices: impl Res<Vec<usize>> + 'static, ) -> Handle<'_, Accordion>
Sets which sections are open by index.
Sourceimpl Handle<'_, AvatarGroup>
impl Handle<'_, AvatarGroup>
Sourcepub fn max_visible(
self,
max_visible: impl Res<usize> + 'static,
) -> Handle<'_, AvatarGroup>
pub fn max_visible( self, max_visible: impl Res<usize> + 'static, ) -> Handle<'_, AvatarGroup>
Limits the number of visible avatars in a group and adds a final overflow avatar with
a +N label when more avatars are present.
Sourceimpl Handle<'_, Badge>
impl Handle<'_, Badge>
Sourceimpl Handle<'_, ButtonGroup>
impl Handle<'_, ButtonGroup>
Sourceimpl Handle<'_, Chip>
impl Handle<'_, Chip>
Sourcepub fn on_close(
self,
callback: impl Fn(&mut EventContext<'_>) + Send + Sync + 'static,
) -> Handle<'_, Chip>
pub fn on_close( self, callback: impl Fn(&mut EventContext<'_>) + Send + Sync + 'static, ) -> Handle<'_, Chip>
Set the callback triggered when the close button of the chip is pressed. The chip close button is not displayed by default. Setting this callback causes the close button to be displayed.
Sourceimpl Handle<'_, Collapsible>
impl Handle<'_, Collapsible>
Sourcepub fn open(self, open: impl Res<bool> + 'static) -> Handle<'_, Collapsible>
pub fn open(self, open: impl Res<bool> + 'static) -> Handle<'_, Collapsible>
Set the open state of the collapsible view.
Sourcepub fn on_toggle(
self,
callback: impl Fn(&mut EventContext<'_>, bool) + 'static,
) -> Handle<'_, Collapsible>
pub fn on_toggle( self, callback: impl Fn(&mut EventContext<'_>, bool) + 'static, ) -> Handle<'_, Collapsible>
Set the callback which is triggered when the open state changes.
Sourceimpl Handle<'_, Dropdown>
impl Handle<'_, Dropdown>
Sourcepub fn placement(
self,
placement: impl Res<Placement> + 'static,
) -> Handle<'_, Dropdown>
pub fn placement( self, placement: impl Res<Placement> + 'static, ) -> Handle<'_, Dropdown>
Sets the position where the tooltip should appear relative to its parent element.
Defaults to Placement::Bottom.
Sourcepub fn show_arrow(
self,
show_arrow: impl Res<bool> + 'static,
) -> Handle<'_, Dropdown>
pub fn show_arrow( self, show_arrow: impl Res<bool> + 'static, ) -> Handle<'_, Dropdown>
Sets whether the popup should include an arrow. Defaults to true.
Sourcepub fn arrow_size<U>(self, size: impl Res<U> + 'static) -> Handle<'_, Dropdown>
pub fn arrow_size<U>(self, size: impl Res<U> + 'static) -> Handle<'_, Dropdown>
Sets the size of the popup arrow, or gap if the arrow is hidden.
Sourceimpl Handle<'_, Label>
impl Handle<'_, Label>
Sourcepub fn describing(
self,
entity_identifier: impl Into<String>,
) -> Handle<'_, Label>
pub fn describing( self, entity_identifier: impl Into<String>, ) -> Handle<'_, Label>
Which form element does this label describe.
Examples
Checkbox::new(cx, value).on_toggle(|cx| cx.emit(AppEvent::ToggleValue)).id("checkbox_identifier");
Label::new(cx, "hello").describing("checkbox_identifier");Sourceimpl Handle<'_, RadioButton>
impl Handle<'_, RadioButton>
Sourcepub fn on_select<F>(self, callback: F) -> Handle<'_, RadioButton>where
F: 'static + Fn(&mut EventContext<'_>),
pub fn on_select<F>(self, callback: F) -> Handle<'_, RadioButton>where
F: 'static + Fn(&mut EventContext<'_>),
Set the callback triggered when the radio button is selected.
Examples
RadioButton::new(cx, value)
.on_select(|cx| cx.emit(AppEvent::ToggleValue));Sourceimpl Handle<'_, ScrollView>
impl Handle<'_, ScrollView>
Sourcepub fn on_scroll(
self,
callback: impl Fn(&mut EventContext<'_>, f32, f32) + Send + Sync + 'static,
) -> Handle<'_, ScrollView>
pub fn on_scroll( self, callback: impl Fn(&mut EventContext<'_>, f32, f32) + Send + Sync + 'static, ) -> Handle<'_, ScrollView>
Sets a callback which will be called when a scrollview is scrolled, either with the mouse wheel, touchpad, or using the scroll bars.
Sourcepub fn scroll_to_cursor(
self,
scroll_to_cursor: impl Res<bool> + 'static,
) -> Handle<'_, ScrollView>
pub fn scroll_to_cursor( self, scroll_to_cursor: impl Res<bool> + 'static, ) -> Handle<'_, ScrollView>
Sets whether the scrollbar should move to the cursor when pressed.
Sourcepub fn scroll_x(
self,
scrollx: impl Res<f32> + 'static,
) -> Handle<'_, ScrollView>
pub fn scroll_x( self, scrollx: impl Res<f32> + 'static, ) -> Handle<'_, ScrollView>
Set the horizontal scroll position of the ScrollView. Accepts a value or signal of type f32 between 0 and 1.
Sourcepub fn scroll_y(
self,
scrolly: impl Res<f32> + 'static,
) -> Handle<'_, ScrollView>
pub fn scroll_y( self, scrolly: impl Res<f32> + 'static, ) -> Handle<'_, ScrollView>
Set the vertical scroll position of the ScrollView. Accepts a value or signal of type f32 between 0 and 1.
Sourcepub fn show_horizontal_scrollbar(
self,
flag: impl Res<bool> + 'static,
) -> Handle<'_, ScrollView>
pub fn show_horizontal_scrollbar( self, flag: impl Res<bool> + 'static, ) -> Handle<'_, ScrollView>
Sets whether the horizontal scrollbar should be visible.
Sourcepub fn show_vertical_scrollbar(
self,
flag: impl Res<bool> + 'static,
) -> Handle<'_, ScrollView>
pub fn show_vertical_scrollbar( self, flag: impl Res<bool> + 'static, ) -> Handle<'_, ScrollView>
Sets whether the vertical scrollbar should be visible.
Sourceimpl Handle<'_, Select>
impl Handle<'_, Select>
Sourcepub fn placeholder<P>(
self,
placeholder: impl Res<P> + 'static,
) -> Handle<'_, Select>where
P: ToStringLocalized + Clone + 'static,
pub fn placeholder<P>(
self,
placeholder: impl Res<P> + 'static,
) -> Handle<'_, Select>where
P: ToStringLocalized + Clone + 'static,
Sets the placeholder text that appears when the textbox has no value.
Sourcepub fn on_select<F>(self, callback: F) -> Handle<'_, Select>
pub fn on_select<F>(self, callback: F) -> Handle<'_, Select>
Sets the callback triggered when an option is selected.
Sourceimpl Handle<'_, Spinbox>
impl Handle<'_, Spinbox>
Sourcepub fn on_change<F>(self, callback: F) -> Handle<'_, Spinbox>
pub fn on_change<F>(self, callback: F) -> Handle<'_, Spinbox>
Sets the callback triggered when the spinbox value is changed.
Sourcepub fn on_increment<F>(self, callback: F) -> Handle<'_, Spinbox>
pub fn on_increment<F>(self, callback: F) -> Handle<'_, Spinbox>
Sets the callback which is triggered when the Spinbox value is incremented.
Sourcepub fn on_decrement<F>(self, callback: F) -> Handle<'_, Spinbox>
pub fn on_decrement<F>(self, callback: F) -> Handle<'_, Spinbox>
Sets the callback which is triggered when the Spinbox value is decremented.
Sourcepub fn vertical<U>(self, vertical: impl Res<U> + 'static) -> Handle<'_, Spinbox>
pub fn vertical<U>(self, vertical: impl Res<U> + 'static) -> Handle<'_, Spinbox>
Sets the orientation of the Spinbox to vertical.
Sourcepub fn icons(
self,
icons: impl Res<SpinboxIcons> + 'static,
) -> Handle<'_, Spinbox>
pub fn icons( self, icons: impl Res<SpinboxIcons> + 'static, ) -> Handle<'_, Spinbox>
Set the icons which should be used for the increment and decrement buttons of the Spinbox
Sourceimpl<R, T> Handle<'_, Textbox<R, T>>
impl<R, T> Handle<'_, Textbox<R, T>>
Sourcepub fn on_edit<F>(self, callback: F) -> Handle<'_, Textbox<R, T>>
pub fn on_edit<F>(self, callback: F) -> Handle<'_, Textbox<R, T>>
Sets the callback triggered when a textbox is edited, i.e. text is inserted/deleted.
Callback provides the current text of the textbox.
Sourcepub fn on_submit<F>(self, callback: F) -> Handle<'_, Textbox<R, T>>
pub fn on_submit<F>(self, callback: F) -> Handle<'_, Textbox<R, T>>
Sets the callback triggered when a textbox is submitted, i.e. when the enter key is pressed with a single-line textbox or the textbox loses focus.
Callback provides the text of the textbox and a flag to indicate if the submit was due to a key press or a loss of focus.
Sourcepub fn on_blur<F>(self, callback: F) -> Handle<'_, Textbox<R, T>>
pub fn on_blur<F>(self, callback: F) -> Handle<'_, Textbox<R, T>>
Sets the callback triggered when a textbox is blurred, i.e. the mouse is pressed outside of the textbox.
Sourcepub fn on_cancel<F>(self, callback: F) -> Handle<'_, Textbox<R, T>>
pub fn on_cancel<F>(self, callback: F) -> Handle<'_, Textbox<R, T>>
Sets the callback triggered when a textbox edit is cancelled, i.e. the escape key is pressed while editing.
Sourcepub fn validate<F>(self, is_valid: F) -> Handle<'_, Textbox<R, T>>
pub fn validate<F>(self, is_valid: F) -> Handle<'_, Textbox<R, T>>
Sets a validation closure which is called when the textbox is edited and sets the validity attribute to the output of the closure.
If a textbox is modified with the validate modifier then the on_submit will not be called if the text is invalid.
Sourcepub fn placeholder<P>(
self,
text: impl Res<P> + 'static,
) -> Handle<'_, Textbox<R, T>>where
P: ToStringLocalized + Clone + 'static,
pub fn placeholder<P>(
self,
text: impl Res<P> + 'static,
) -> Handle<'_, Textbox<R, T>>where
P: ToStringLocalized + Clone + 'static,
Sets the placeholder text that appears when the textbox has no value.
Sourceimpl Handle<'_, ToggleButton>
impl Handle<'_, ToggleButton>
Sourcepub fn on_toggle(
self,
callback: impl Fn(&mut EventContext<'_>) + 'static,
) -> Handle<'_, ToggleButton>
pub fn on_toggle( self, callback: impl Fn(&mut EventContext<'_>) + 'static, ) -> Handle<'_, ToggleButton>
Sets the callback triggered when the ToggleButton is toggled.
Sourceimpl Handle<'_, Tooltip>
impl Handle<'_, Tooltip>
Sourcepub fn placement<U>(
self,
placement: impl Res<U> + 'static,
) -> Handle<'_, Tooltip>
pub fn placement<U>( self, placement: impl Res<U> + 'static, ) -> Handle<'_, Tooltip>
Sets the position where the tooltip should appear relative to its parent element.
Defaults to Placement::Bottom.
Sourceimpl Handle<'_, VirtualList>
impl Handle<'_, VirtualList>
Sourcepub fn selection<R>(
self,
selection: impl Res<R> + 'static,
) -> Handle<'_, VirtualList>
pub fn selection<R>( self, selection: impl Res<R> + 'static, ) -> Handle<'_, VirtualList>
Sets the selected items of the list from a signal of indices.
Sourcepub fn on_select<F>(self, callback: F) -> Handle<'_, VirtualList>
pub fn on_select<F>(self, callback: F) -> Handle<'_, VirtualList>
Sets the callback triggered when a ListItem is selected.
Sourcepub fn selectable<U>(
self,
selectable: impl Res<U> + 'static,
) -> Handle<'_, VirtualList>
pub fn selectable<U>( self, selectable: impl Res<U> + 'static, ) -> Handle<'_, VirtualList>
Set the selectable state of the List.
Sourcepub fn selection_follows_focus<U>(
self,
flag: impl Res<U> + 'static,
) -> Handle<'_, VirtualList>
pub fn selection_follows_focus<U>( self, flag: impl Res<U> + 'static, ) -> Handle<'_, VirtualList>
Sets whether the selection should follow the focus.
Sourcepub fn scroll_to_cursor(self, flag: bool) -> Handle<'_, VirtualList>
pub fn scroll_to_cursor(self, flag: bool) -> Handle<'_, VirtualList>
Sets whether the scrollbar should move to the cursor when pressed.
Sourcepub fn on_scroll(
self,
callback: impl Fn(&mut EventContext<'_>, f32, f32) + Send + Sync + 'static,
) -> Handle<'_, VirtualList>
pub fn on_scroll( self, callback: impl Fn(&mut EventContext<'_>, f32, f32) + Send + Sync + 'static, ) -> Handle<'_, VirtualList>
Sets a callback which will be called when a scrollview is scrolled, either with the mouse wheel, touchpad, or using the scroll bars.
Sourcepub fn scroll_x(
self,
scrollx: impl Res<f32> + 'static,
) -> Handle<'_, VirtualList>
pub fn scroll_x( self, scrollx: impl Res<f32> + 'static, ) -> Handle<'_, VirtualList>
Set the horizontal scroll position of the ScrollView. Accepts a value or lens to an ‘f32’ between 0 and 1.
Sourcepub fn scroll_y(
self,
scrollx: impl Res<f32> + 'static,
) -> Handle<'_, VirtualList>
pub fn scroll_y( self, scrollx: impl Res<f32> + 'static, ) -> Handle<'_, VirtualList>
Set the vertical scroll position of the ScrollView. Accepts a value or lens to an ‘f32’ between 0 and 1.
Sourcepub fn show_horizontal_scrollbar(
self,
flag: impl Res<bool> + 'static,
) -> Handle<'_, VirtualList>
pub fn show_horizontal_scrollbar( self, flag: impl Res<bool> + 'static, ) -> Handle<'_, VirtualList>
Sets whether the horizontal scrollbar should be visible.
Sourcepub fn show_vertical_scrollbar(
self,
flag: impl Res<bool> + 'static,
) -> Handle<'_, VirtualList>
pub fn show_vertical_scrollbar( self, flag: impl Res<bool> + 'static, ) -> Handle<'_, VirtualList>
Sets whether the vertical scrollbar should be visible.